@@ -42,7 +42,15 @@ RadialMap::Widget::path() const
 KURL
 RadialMap::Widget::url( File const * const file ) const
 {
-   return KURL::fromPathOrURL( file ? file->fullPath() : m_tree->fullPath() );
+   if (file)
+   {
+      return KURL::fromPathOrURL(file->fullPath());
+   }
+   if (m_tree)
+   {
+      return KURL::fromPathOrURL(m_tree->fullPath());
+   }
+   return KURL::fromPathOrURL(TQString::null);
 }
 
 void
